@@ -2,14 +2,14 @@ package Web::Request::Role::AbsoluteUriFor;
 
 # ABSTRACT: Construct an absolute URI honoring script_name
 
-our $VERSION = '1.003'; # VERSION
+our $VERSION = '1.004'; # VERSION
 
 use 5.010;
 use Moose::Role;
 use Plack::Response;
 
 sub absolute_uri_for {
-    my ( $self, $uri_for ) = @_;
+    my ( $self, $uri_for, $base_uri ) = @_;
 
     my $url;
     if ( ref($uri_for) eq 'HASH' ) {
@@ -20,7 +20,7 @@ sub absolute_uri_for {
     }
 
     my $script_name = $self->script_name || '';
-    my $base_uri = $self->base_uri;
+    $base_uri ||= $self->base_uri;
 
     $base_uri=~s{/+$}{};
     $script_name=~s{/+$}{};
@@ -46,7 +46,7 @@ Web::Request::Role::AbsoluteUriFor - Construct an absolute URI honoring script_n
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -64,7 +64,11 @@ version 1.003
 
   # redirect
   $req->absolute_uri_for({ controller=>'foo', action=>'bar' });
-  # http://yoursite.com/mountpoint/foo/bar
+  # https://yoursite.com/mountpoint/foo/bar
+
+  # don't use the base-uri from $req by passing an explit additional value
+  $req->absolute_uri_for({ controller=>'foo', action=>'bar' }, 'https://example.com');
+  # https://example.com/mountpoint/foo/bar
 
 =head1 DESCRIPTION
 
@@ -76,11 +80,17 @@ C<Web::Request::Role::AbsoluteUriFor> provides a method to calculate the absolut
 
     $req->absolute_uri_for( '/some/path' );
     $req->absolute_uri_for( $ref_uri_for );
+    $req->absolute_uri_for( '/some/path', $base-url );
 
 Construct an absolute URI out of C<base_uri>, C<script_name> and the
-passed in string.  You can also pass a ref, which will be resolved by
+passed in string. You can also pass a ref, which will be resolved by
 calling C<uri_for> on the request object.
 
+If you pass a second argument, this value will be used as the base-uri
+instead of extracting it from the request. This can make sense when
+you for exampel host a white lable service and need to generate
+different links based on some value inside your app.
+
 =head1 THANKS
 
 Thanks to
